@@ -218,7 +218,7 @@ class Dataset:
             return (x - self.x_stats['mean']) / self.x_stats['std']
         elif self.normalisation_x == 'max_min':
             if verbose:
-                print('Normalising inputs with max-min values: [%.4f, %.4f]' % (self.n_ranges_x[0], self.n_ranges_x[1]))
+                print('Normalising inputs with max-min values')
             return (x - self.n_ranges_x[0]) / (self.n_ranges_x[1] - self.n_ranges_x[0])
         elif self.normalisation_x is None:
             if verbose:
@@ -995,4 +995,4 @@ class ClientFunction:
         y2 = y[n_params:]
         grads = (y1 - y2) / (2 * step)
 
-        return grads
\ No newline at end of file
+        return grads
